Crate scalar_cms

Crate scalar_cms 

Re-exports

pub use db::DatabaseConnection;
pub use editor_field::EditorField;
pub use editor_type::EditorType;
pub use serde_json;
pub use scalar_expr as expr;

Modules

db
editor_field
editor_type
types
validations

Macros

nanoid

Structs

DateTime
ISO 8601 combined date and time with time zone.
DocInfo
Item
NaiveDate
ISO 8601 calendar date without timezone. Allows for every proleptic Gregorian date from Jan 1, 262145 BCE to Dec 31, 262143 CE. Also supports the conversion from ISO 8601 ordinal and week date.
Schema
Utc
The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).

Traits

Document

Attribute Macros

doc_enum
Sets up an enum for use in a Document. This macro does a couple of things:

Derive Macros

Document
Derives the document trait.
EditorField
Derives EditorField.
Enum