pub struct Valid<T: Document>(/* private fields */);Expand description
A wrapper type to indicate that the inner type is valid.
Implementations
Sourceimpl<T: Document + Sync> Valid<T>
impl<T: Document + Sync> Valid<T>
Sourcepub async fn new<DB: DatabaseConnection + ContentActions<T> + Sync>(
val: T,
ctx: ValidationContext<'_, DB, T>,
) -> Result<Self, ValidationError>
pub async fn new<DB: DatabaseConnection + ContentActions<T> + Sync>( val: T, ctx: ValidationContext<'_, DB, T>, ) -> Result<Self, ValidationError>
Validates the input, then returns a Valid
Errors
This function will return an error if validation fails.
pub fn inner(self) -> T